from __future__ import unicode_literals
from enum import IntEnum
import serial


class Animation(IntEnum):
    none, waking_up, standby, listening, error = range(5)


class Animator(object):
    def __init__(self, port, debug=False):
        self.serial = serial.Serial()
        self.serial.baudrate = 9600
        self.serial.timeout = 0.5
        self.serial.port = port
        self.debug = debug

    def open(self):
        self.serial.open()

    def close(self):
        self.serial.close()

    def run(self, animation):
        self.serial.write(bytearray([animation.value]))
        if self.debug:
            while self.serial.in_waiting:
              print('received {}'.format(self.serial.readline()))
            print('sent {}'.format(animation.name))
            print('received {}'.format(self.serial.readline()))




# -*-: coding utf-8 -*-
""" Neopixel skill for Snips. """

from __future__ import unicode_literals
from lights import Animator, Animation
import atexit


class SnipsNeopixel:
    """NeoPixel skill for Snips."""

    def __init__(self, arduino_port='/dev/ttyACM0', debug=False, locale=None):
        try:
            self.animator = Animator(arduino_port, debug)
            self.animator.open()
            self.animator.run(Animation.waking_up)
            atexit.register(self.close)
        except Exception as ex:
            print(ex)
            self.animator = None
            pass

    def stand_by(self):
        self.animator.run(Animation.standby)

    def listening(self):
        self.animator.run(Animation.listening)

    def waking_up(self):
        self.animator.run(Animation.waking_up)

    def error(self):
        self.animator.run(Animation.error)

    def none(self):
        self.animator.run(Animation.none)

    def close(self):
        self.none()
        self.animator.close()






from setuptools import setup

setup(
    name='snipsneopixel',
    version='0.1.0',
    description='NeoPixel skill for Snips',
    author='',
    url='https://github.com/snipsco/snips-skill-neopixel',
    download_url='',
    license='MIT',
    install_requires=[
        "enum34==1.1.6",
        "pyserial"
    ],
    test_suite="tests",
    keywords=['snips', 'neopixel'],
    packages=['snipsneopixel'],
    package_data={'snipsneopixel': ['Snipsspec']},
    include_package_data=True,
)
